@@ -90,5 +90,3 @@
 /* Type unsigned long long is stored BIG-ENDIAN in memory (i.e. like mc68000 or sparc). */
 #define long_long_big_endian
 
-/* Stack grows up, ca. 1 bytes per function call. */
-#define stack_grows_up
